@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12000 2020-03-24 16:39:06Z Trista $
+# $Id: __init__.py 12020 2020-03-26 11:24:20Z Trista $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $ (last)
-# $Date: 2020-03-25 00:39:06 +0800 (週三, 25 三月 2020) $
-# $Revision: 12000 $
+# $Date: 2020-03-26 20:24:20 +0900 (週四, 26 三月 2020) $
+# $Revision: 12020 $
 
 from __future__ import print_function
 
@@ -212,13 +212,16 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     args = sys.argv
 
     # if the command is manage.py runserver, then print the SERVER_MODE
-    if (args[0].endswith('manage.py')) and (args[1]=='runserver'):
-        warns = True
-        printDetail = True
-        
+    if len(args) >= 2:
+        if (args[0].endswith('manage.py')) and (args[1] == 'runserver'):
+            pass
+        else:
+            warns = False
+            printDetail = False
+            
     # if the command is not manage.py runserver(ex: cms_dumpdata), do NOT print SERVER_MODE
     else:
-        warns=False
+        warns = False
         printDetail = False
     
     settingsPath = os.path.abspath(settingsDict['__file__'])
