@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 11907 2020-02-06 03:48:51Z Trista $
+# $Id: forms.py 11982 2020-03-19 11:39:46Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Trista $ (last)
-# $Date: 2020-02-06 12:48:51 +0900 (週四, 06 二月 2020) $
-# $Revision: 11907 $
+# $Author: Lavender $ (last)
+# $Date: 2020-03-19 20:39:46 +0900 (週四, 19 三月 2020) $
+# $Revision: 11982 $
 
 import os
 import re
@@ -654,7 +654,7 @@ class BonusSettingsForm(forms.ModelForm):
     class Meta:
         model = BonusSettings
         fields = ['consumption', 'percent', 'discount', 
-                  'limit', 'receiveStatus', 'includeRange', 'excludeRange']
+                  'limit', 'receiveStatus', 'includeRange', 'excludeRange', 'expiryDays']
         
 class BonusForm(forms.Form):
     quantity = forms.IntegerField(
